@@ -6,8 +6,15 @@ import os
 import urllib2
 import requests
 
-from libturpial.common import *
-from libturpial.exceptions import *
+from libturpial.common import (NUM_STATUSES,
+                               ColumnType,
+                               is_preview_service_supported,
+                               get_preview_service_from_url,
+                               unescape_list_name)
+from libturpial.exceptions import (URLAlreadyShort,
+                                   NoURLToShorten,
+                                   PreviewServiceNotSupported,
+                                   UserListNotFound)
 from libturpial.config import AppConfig
 from libturpial.common.tools import get_urls
 from libturpial.api.models.proxy import Proxy
@@ -23,13 +30,13 @@ from libturpial.api.managers.columnmanager import ColumnManager
 
 class Core:
     """
-    This is the main object in libturpial. This should be the only class you need to
-    instantiate to use libturpial. Most important arguments used in Core are
-    *account_id* and *column_id*.
+    This is the main object in libturpial. This should be the only class you
+    need to instantiate to use libturpial. Most important arguments used in
+    Core are *account_id* and *column_id*.
 
-    * account_id: Is a composite string formed by the **username** and the 
+    * account_id: Is a composite string formed by the **username** and the
       **protocol_id** that identify every single account.
-    * column_id: Is composite string formed by **account_id** and the 
+    * column_id: Is composite string formed by **account_id** and the
       **column_name** that identify one column of one account.
 
     Examples of account_id:
@@ -43,28 +50,36 @@ class Core:
     >>> identica_replies = 'foo-identica-replies'
 
     When you instantiate Core it will load all registered accounts
-    automatically, so you don't need to worry about it. If you already registered the
-    accounts before, they will be available after you create the core object.
+    automatically, so you don't need to worry about it. If you already
+    registered the accounts before, they will be available after you create
+    the core object.
 
-    All the Core methods will return an object defined in 
-    :class:`libturpial.api.models` or a valid python object if request is 
+    All the Core methods will return an object defined in
+    :class:`libturpial.api.models` or a valid python object if request is
     successful, otherwise they will raise an exception.
 
     If the request returns an array, you can iterate over the elements with:
 
-    >>> for object in response:
-    >>>     print object
+    >>> core = Core()
+    >>> followers = core.get_followers('username-protocol')
+    >>> [follower for follower in followers]
 
     In all the following functions the following apply:
         *account_id* must be a string ("username-service")
         *column_id* must be a string ("columnname-username-service")
     """
 
-    def __init__(self):
+    def __init__(self, load_accounts=True):
         self.config = AppConfig()
-        self.account_manager = AccountManager(self.config)
+        self.accman = AccountManager(self.config, load_accounts)
         self.column_manager = ColumnManager(self.config)
 
+    def __get_upload_media_object(self, service):
+        return UPLOAD_MEDIA_SERVICES[service]
+
+    def __get_short_url_object(self, service):
+        return URL_SERVICES[service]
+
     def filter_statuses(self, statuses):
         filtered_statuses = []
         filtered_terms = self.config.load_filters()
@@ -72,18 +87,24 @@ class Core:
             return statuses
 
         for status in statuses:
+            filtered = False
             for term in map(lambda x: x.lower(), filtered_terms):
                 if term.startswith('@'):
                     # Filter statuses by user
                     if status.username.lower() == term[1:]:
-                        continue
+                        filtered = True
+                        break
                     # Filter statuses repeated by filtered users
                     elif status.repeated_by:
-                        if status.repeated_by.lower().find(term[1:]) >= 0:
-                            continue
+                        if status.repeated_by.lower() == term[1:]:
+                            filtered = True
+                            break
                 else:
                     if status.text.lower().find(term) >= 0:
+                        filtered = True
                         continue
+
+            if status not in filtered_statuses and not filtered:
                 filtered_statuses.append(status)
         return filtered_statuses
 
@@ -104,7 +125,7 @@ class Core:
 
         >>> ['foo-twitter', 'foo-identica']
         """
-        return self.account_manager.list()
+        return self.accman.list()
 
     def register_account(self, account):
         # TODO: Add documention/reference for account validation
@@ -117,24 +138,30 @@ class Core:
 
         Return a string with the id of the account registered.
         """
-        return self.account_manager.register(account)
+        return self.accman.register(account)
 
     def unregister_account(self, account_id, delete_all=False):
         """
-        Removes the account identified by *account_id* from memory. If 
-        *delete_all* is **True** it deletes all the files asociated to 
+        Removes the account identified by *account_id* from memory. If
+        *delete_all* is **True** it deletes all the files asociated to
         that account from disk otherwise the account will be available
         the next time you load Core.
 
         Return a string with the id of the account unregistered.
         """
-        return self.account_manager.unregister(account_id, delete_all)
+        return self.accman.unregister(account_id, delete_all)
 
     def all_columns(self):
+        # TODO: add __str__ function to libturpial.api.models.column.Column
+        # objects
         """
         Return a dictionary with all columns per account. Example:
 
-        >>> {'foo-twitter': ['timeline', 'direct', 'sent', 'favorites']}
+        >>> {'foo-twitter': [libturpial.api.models.Column foo-twitter-timeline,
+            libturpial.api.models.Column foo-twitter-replies,
+            libturpial.api.models.Column foo-twitter-direct,
+            libturpial.api.models.Column foo-twitter-sent,
+            libturpial.api.models.Column foo-twitter-favorites]}
         """
         columns = {}
         for account in self.registered_accounts():
@@ -143,10 +170,9 @@ class Core:
                 columns[account.id_].append(column)
         return columns
 
-
     def register_column(self, column_id):
         """
-        Register a column identified by *column_id* column and return a string 
+        Register a column identified by *column_id* column and return a string
         with the id of the column registered on success.
         """
         return self.column_manager.register(column_id)
@@ -166,13 +192,14 @@ class Core:
         """
         return Protocol.availables()
 
-
     def available_columns(self):
         """
         Return a dictionary with all available (non-registered-yet)
         columns per account. Example:
 
-        >>> {'foo-twitter': ['timeline', 'direct', 'sent', 'favorites']}
+        >>> {'foo-twitter': [libturpial.api.models.Column foo-twitter-direct,
+            libturpial.api.models.Column foo-twitter-replies,
+            libturpial.api.models.Column foo-twitter-sent]}
         """
         columns = {}
         for account in self.registered_accounts():
@@ -187,7 +214,7 @@ class Core:
         Return a *dict* with :class:`libturpial.api.models.column.Column` objects
         per column registered. This method DO NOT return columns in the order they
         have been registered. For ordered columns check
-        :method:`registered_columns_by_order()`
+        :meth:`registered_columns_by_order()`
         """
         return self.column_manager.columns()
 
@@ -203,7 +230,7 @@ class Core:
         Return a *dict* with all registered accounts as an array of
         :class:`libturpial.api.models.account.Account` objects registered
         """
-        return self.account_manager.accounts()
+        return self.accman.accounts()
 
     def get_single_column(self, column_id):
         """
@@ -217,7 +244,7 @@ class Core:
         Return the :class:`libturpial.api.models.account.Account` object identified
         with *account_id*
         """
-        return self.account_manager.get(account_id)
+        return self.accman.get(account_id)
 
 
     ###########################################################################
@@ -227,17 +254,16 @@ class Core:
     def get_column_statuses(self, account_id, column_id,
                             count=NUM_STATUSES, since_id=None):
         """
-        Fetch the statuses for the account *account_id* and the column *column_id*.
-        *count* let you specify how many statuses do you want to fetch, values
-        range goes from 0-200. If *since_id* is not **None** libturpial will
-        only fetch statuses newer than that.
-
+        Fetch the statuses for the account *account_id* and the column
+        *column_id*. *count* let you specify how many statuses do you want to
+        fetch, values range goes from 0-200. If *since_id* is not **None**
+        libturpial will only fetch statuses newer than that.
         """
         if column_id.find(ColumnType.SEARCH) == 0:
             criteria = column_id[len(ColumnType.SEARCH) + 1:]
             return self.search(account_id, criteria, count, since_id)
 
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         if column_id == ColumnType.TIMELINE:
             rtn = account.get_timeline(count, since_id)
         elif column_id == ColumnType.REPLIES:
@@ -251,45 +277,49 @@ class Core:
         elif column_id == ColumnType.PUBLIC:
             rtn = account.get_public_timeline(count, since_id)
         else:
-            list_id = account.get_list_id(column_id)
+            column_slug = unescape_list_name(column_id)
+            list_id = account.get_list_id(column_slug)
             if list_id is None:
                 raise UserListNotFound
             rtn = account.get_list_statuses(list_id, count, since_id)
         return rtn
 
-    def get_public_timeline(self, account_id, count=NUM_STATUSES, since_id=None):
+    def get_public_timeline(self, account_id, count=NUM_STATUSES,
+                            since_id=None):
         # TODO: Remove this function and replace with streamming api
         """
         Fetch the public timeline for the service associated to the
         account *account_id*. *count* and *since_id* work in the same way
         that in :meth:`libturpial.api.core.Core.get_column_statuses`
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         return account.get_public_timeline(count, since_id)
 
     def get_followers(self, account_id, only_id=False):
+        # TODO: define __str__ function for
+        # in libturpial.api.models.profile.Profile Class
         """
-        Return a :class:`libturpial.api.models.profile.Profile` list with 
+        Returns a :class:`libturpial.api.models.profile.Profile` list with
         all the followers of the account *account_id*
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         return account.get_followers(only_id)
 
     def get_following(self, account_id, only_id=False):
         """
-        Return a :class:`libturpial.api.models.profile.Profile` list of 
+        Returns a :class:`libturpial.api.models.profile.Profile` list of
         all the accounts that *account_id* follows
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         return account.get_following(only_id)
 
     def get_all_friends_list(self):
         """
-        Return a list with all the username friends of all the registered 
+        Return a list with all the username friends of all the registered
         accounts.
         """
         friends = []
-        for account in self.account_manager.accounts():
+        for account in self.accman.accounts():
             for profile in account.get_following():
                 if profile.username not in friends:
                     friends.append(profile.username)
@@ -304,7 +334,7 @@ class Core:
         Return the profile of the *user*, using the *account_id*,
         if user is None, it returns the profile of account_id itself.
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         if user:
             profile = account.get_profile(user)
             profile.followed_by = account.is_friend(user)
@@ -314,26 +344,28 @@ class Core:
         return profile
 
     def get_conversation(self, account_id, status_id):
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         return account.get_conversation(status_id)
 
     def update_status(self, account_id, text, in_reply_id=None, media=None):
         """
         Updates the account *account_id* with content of *text*
 
-        if *in_reply_id* is not None, specifies the tweets that is being answered.
+        if *in_reply_id* is not None, specifies the tweets that is being
+        answered.
 
         *media* can specify the filepath of an image. If not None, the status is posted with
         the image attached. At this moment, this method is only valid for Twitter.
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         return account.update_status(text, in_reply_id, media)
 
     def broadcast_status(self, account_id_array, text):
+        # TODO: add __str__ to libturpial.api.models.account.Account
         """
         Updates all the accounts in account_id_array with the content of *text*
 
-        if account_id_array is None or an empty list all registered accounts 
+        if account_id_array is None or an empty list all registered accounts
         get updated.
         """
         if not account_id_array:
@@ -342,7 +374,7 @@ class Core:
         response = {}
         for account_id in account_id_array:
             try:
-                account = self.account_manager.get(account_id)
+                account = self.accman.get(account_id)
                 response[account_id] = account.update_status(text)
             except Exception, exc:
                 response[account_id] = exc
@@ -352,61 +384,65 @@ class Core:
         """
         Deletes status of *account_id* specified by *status_id*
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         return account.destroy_status(status_id)
 
     def get_single_status(self, account_id, status_id):
         """
-        Retrieves a single status with *account_id* that corresponds with *status_id*
+        Retrieves a single status with *account_id* that corresponds with
+        *status_id*
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         return account.get_status(status_id)
 
     def repeat_status(self, account_id, status_id):
         """
         Allows to send the same status again by using repeat option in API
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         return account.repeat_status(status_id)
 
     def mark_status_as_favorite(self, account_id, status_id):
         """
         Marks status of *account_id* specified by *status_id* as favorite
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         return account.mark_as_favorite(status_id)
 
     def unmark_status_as_favorite(self, account_id, status_id):
         """
         Unmarks status of *account_id* specified by *status_id* as favorite
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         return account.unmark_as_favorite(status_id)
 
     def send_direct_message(self, account_id, username, message):
         """
-        Sends a direct update with the contant of *message* to *username* using *account_id*
+        Sends a direct update with the contant of *message* to *username* using
+        *account_id*
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         return account.send_direct_message(username, message)
 
     def destroy_direct_message(self, account_id, status_id):
         """
         Deletes a direct update from *account_id* defined by its *status_id*
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         return account.destroy_direct_message(status_id)
 
+    # TODO: Validate at least one of the parameters
     def update_profile(self, account_id, fullname=None, url=None, bio=None,
-            location=None):
+                       location=None):
         """
-        Updates the *account_id* public profile with the information in variables
+        Updates the *account_id* public profile with the information in
+        variables
         fullname = Complete account name
         url = Blog or personal URL of the account
         bio = Small resume
         location = Geographic location
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         return account.update_profile(fullname, url, bio, location)
 
     def follow(self, account_id, username, by_id=False):
@@ -414,7 +450,7 @@ class Core:
         Makes *account_id* a follower of *username*.
         Return a :class:`libturpial.api.models.profile.Profile` object with the user profile
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         response = account.follow(username, by_id)
         self.add_friend(username)
         return response
@@ -424,7 +460,7 @@ class Core:
         Stops *account_id* from being a follower of *username*.
         Return a :class:`libturpial.api.models.profile.Profile` object with the user profile
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         response = account.unfollow(username)
         self.remove_friend(username)
         return response
@@ -434,7 +470,7 @@ class Core:
         Blocks *username* in *account_id*.
         Return a :class:`libturpial.api.models.profile.Profile` object with the user profile
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         response = account.block(username)
         self.remove_friend(username)
         return response
@@ -444,7 +480,7 @@ class Core:
         Unblocks *username* in *account_id*.
         Return a :class:`libturpial.api.models.profile.Profile` object with the user profile
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         return account.unblock(username)
 
     def report_as_spam(self, account_id, username):
@@ -452,7 +488,7 @@ class Core:
         Reports *username* as SPAM using *account_id*.
         Return a :class:`libturpial.api.models.profile.Profile` object with the user profile
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         response = account.report_as_spam(username)
         self.remove_friend(username)
         return response
@@ -467,7 +503,7 @@ class Core:
 
     def unmute(self, username):
         """
-        Removes *username* from the muted list, so that statuses from 
+        Removes *username* from the muted list, so that statuses from
         that account are now shown
         """
         self.config.remove_filter('@%s' % username)
@@ -475,13 +511,14 @@ class Core:
 
     def verify_friendship(self, account_id, username):
         """
-        Return *True* if the owner of *account_id* and *username* are following each other.
-        *False* otherwise.
+        Check if *username* is on only followed by *account_id* but if he also
+        follows *account_id*
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         return account.is_friend(username)
 
-    def search(self, account_id, query, count=NUM_STATUSES, since_id=None, extra=None):
+    def search(self, account_id, query, count=NUM_STATUSES, since_id=None,
+               extra=None):
         """
         Performs a search using Twitter API, defined by:
         account_id = Account to be used for the search
@@ -489,7 +526,7 @@ class Core:
         acount = Max number of results
         since_id = if limited to a status id and on.
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         # The unquote is to ensure that the query is not url-encoded. The
         # encoding will be done automatically by the http module
         unquoted_query = urllib2.unquote(query)
@@ -497,11 +534,11 @@ class Core:
 
     def get_profile_image(self, account_id, username, use_cache=True):
         """
-        Return the local path to a the profile image of *username* in original size.
-        If use_cache is *True* it will try to return the cached file, otherwise it 
-        will fetch the real image.
+        Returns the local path to a the profile image of *username* in original
+        size. If use_cache is *True* it will try to return the cached file,
+        otherwise it will fetch the real image.
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         basename = "%s-%s-profile-image" % (account_id, username)
         img_destination_path = os.path.join(account.config.imgdir, basename)
         if not os.path.isfile(img_destination_path) or use_cache == False:
@@ -513,10 +550,12 @@ class Core:
 
     def get_status_avatar(self, status):
         """
-        Return the local path to a the profile image of the username to post *status* in 48x48 px size
+        Returns the local path to a the profile image of the username to post
+        *status* in 48x48 px size
         """
-        account = self.account_manager.get(status.account_id)
-        basename = "%s-%s-avatar-%s" % (status.account_id, status.username, os.path.basename(status.avatar))
+        account = self.accman.get(status.account_id)
+        basename = "%s-%s-avatar-%s" % (status.account_id, status.username,
+                                        os.path.basename(status.avatar))
         img_destination_path = os.path.join(account.config.imgdir, basename)
         if not os.path.isfile(img_destination_path):
             fp = open(img_destination_path, 'w')
@@ -529,7 +568,7 @@ class Core:
         Return an array of :class:`libturpial.api.models.trend.TrendLocation` objects with all the
         locations with trending topics registered.
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         return account.available_trend_locations()
 
     def get_trending_topics(self, account_id, location_id):
@@ -537,7 +576,7 @@ class Core:
         Return an array of :class:`libturpial.api.models.trend.Trend` objects with trending topics
         for the specified location. *location_id* is the Yahoo! Where On Earth ID for the location.
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         return account.trends(location_id)
 
     def update_profile_image(self, account_id, image_path):
@@ -546,7 +585,7 @@ class Core:
         Return a :class:`libturpial.api.models.profile.Profile` object
         with the user profile updated.
         """
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         return account.update_profile_image(image_path)
 
     ###########################################################################
@@ -560,7 +599,7 @@ class Core:
         service = self.get_shorten_url_service()
         if os.path.split(long_url)[0].find(service) >= 0:
             raise URLAlreadyShort
-        urlshorter = URL_SERVICES[service]
+        urlshorter = self.__get_short_url_object(service)
         return urlshorter.do_service(long_url)
 
     def short_url_in_message(self, message):
@@ -592,18 +631,19 @@ class Core:
 
     def upload_media(self, account_id, filepath, message=None):
         service = self.get_upload_media_service()
-        account = self.account_manager.get(account_id)
-        uploader = UPLOAD_MEDIA_SERVICES[service]
+        account = self.accman.get(account_id)
+        uploader = self.__get_upload_media_object(service)
         return uploader.do_service(account, filepath, message)
 
     ###########################################################################
     # Configuration API
     ###########################################################################
 
+    # TODO: Return added option?
     def register_new_config_option(self, section, option, default_value):
         """
-        Register a new configuration *option* in *section* to be handled by 
-        external modules. libturpial will set *default_value* as value if 
+        Register a new configuration *option* in *section* to be handled by
+        external modules. libturpial will set *default_value* as value if
         the option doesn't exist.
 
         This method should be used if a module that uses libturpial needs to
@@ -631,16 +671,18 @@ class Core:
     def set_upload_media_service(self, value):
         return self.config.write('Services', 'upload-pic', value)
 
+    # WARN: Will be deprecated on next mayor version
     def has_stored_passwd(self, account_id):
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         if account.profile.password is None:
             return False
         if account.profile.password == '':
             return False
         return True
 
+    # WARN: Will be deprecated on next mayor version
     def is_account_logged_in(self, account_id):
-        account = self.account_manager.get(account_id)
+        account = self.accman.get(account_id)
         return account.logged_in
 
     def is_muted(self, username):
@@ -705,7 +747,7 @@ class Core:
         """
         Return the timeout set for the socket connections
         """
-        return self.config.get_socket_timeout()
+        return int(self.config.get_socket_timeout())
 
     # WARN: Will be deprecated on next mayor version
     def get_update_interval(self):
@@ -716,6 +758,7 @@ class Core:
         minimize = self.config.read('General', 'minimize-on-close')
         return True if minimize == 'on' else False
 
+    # Should it be deprecated?
     # WARN: Will be deprecated on next mayor version
     def get_config(self):
         return self.config.read_all()
@@ -724,6 +767,7 @@ class Core:
     def read_config_value(self, section, option):
         return self.config.read(section, option)
 
+    # Should it be deprecated?
     # WARN: Will be deprecated on next mayor version
     def write_config_value(self, section, option, value):
         self.config.write(section, option, value)
@@ -738,18 +782,21 @@ class Core:
         """
         return self.config.load_filters()
 
+    # TODO: Return saved filters or True
     def save_filters(self, lst):
         """
         Save *lst* a the new filters list
         """
         self.config.save_filters(lst)
 
+    # TODO: Return True on success
     def delete_current_config(self):
         """
         Delete current configuration file. This action can not be undone
         """
         self.config.delete()
 
+    # TODO: Return True on success
     def delete_cache(self):
         """
         Delete all files in cache
@@ -766,6 +813,7 @@ class Core:
             total_size += account.get_cache_size()
         return total_size
 
+    # TODO: Return added friend
     def add_friend(self, username):
         """
         Save *username* into the friends list
@@ -774,6 +822,7 @@ class Core:
         friends.append(username)
         self.config.save_friends(friends)
 
+    # TODO: Return removed friend
     def remove_friend(self, username):
         """
         Remove *username* from friends list
