@@ -10,8 +10,8 @@ import ConfigParser
 
 from libturpial.api.models.proxy import Proxy
 from libturpial.common import get_username_from, get_protocol_from
-from libturpial.exceptions import EmptyOAuthCredentials, EmptyBasicCredentials, \
-        ExpressionAlreadyFiltered
+from libturpial.exceptions import EmptyOAuthCredentials, \
+    ExpressionAlreadyFiltered
 
 try:
     from xdg import BaseDirectory
@@ -20,7 +20,7 @@ except:
     XDG_CACHE = False
 
 APP_CFG = {
-    'General':{
+    'General': {
         'update-interval': '5',
         'queue-interval': '30',
         'minimize-on-close': 'on', # TODO: Deprecate in next mayor version
@@ -30,7 +30,7 @@ APP_CFG = {
     },
     'Services':{
         'shorten-url': 'is.gd',
-        'upload-pic': 'twitpic',
+        'upload-pic': 'pic.twitter.com',
     },
     'Proxy':{
         'username': '',
@@ -65,7 +65,7 @@ ACCOUNT_CFG = {
         'key': '',
         'secret': '',
     },
-    'Login':{
+    'Login': {
         'username': '',
         'protocol': '',
     }
@@ -74,6 +74,7 @@ ACCOUNT_CFG = {
 USERDIR = os.path.expanduser('~')
 BASEDIR = os.path.join(USERDIR, '.config', 'turpial')
 
+
 class ConfigBase:
     """Base configuration"""
     def __init__(self, default=None):
@@ -87,6 +88,10 @@ class ConfigBase:
         self.extra_sections = {}
 
     def register_extra_option(self, section, option, default_value):
+        if section in self.__config:
+            if option in self.__config[section]:
+                return
+
         if not self.extra_sections.has_key(section):
             self.extra_sections[section] = {}
         self.extra_sections[section][option] = default_value
@@ -97,6 +102,7 @@ class ConfigBase:
             for option, value in self.default[section].iteritems():
                 self.write(section, option, value)
 
+    # TODO: Return True on success?
     def load(self):
         self.__config = dict(self.default)
         self.__config.update(self.extra_sections)
@@ -124,7 +130,6 @@ class ConfigBase:
         if on_disk != on_memory:
             self.save()
 
-
     def load_failsafe(self):
         self.__config = self.default
 
@@ -153,10 +158,18 @@ class ConfigBase:
     def write_section(self, section, items):
         if self.cfg.has_section(section):
             self.cfg.remove_section(section)
-            self.__config[section] = {}
+            self.cfg.add_section(section)
+        else:
+            self.cfg.add_section(section)
+        self.__config[section] = {}
 
         for option, value in items.iteritems():
-            self.write(section, option, value)
+            self.__config[section][option] = value
+            self.cfg.set(section, option, value)
+
+        _fd = open(self.configpath, 'w')
+        self.cfg.write(_fd)
+        _fd.close()
 
     # WARN: Next version boolean will be the default answer
     def read(self, section, option, boolean=False):
@@ -175,26 +188,25 @@ class ConfigBase:
             return None
 
     def read_section(self, section):
-        #self.log.debug('Reading section %s' % section)
         try:
             return self.__config[section]
         except Exception:
             return None
 
     def read_all(self):
-        self.log.debug('Reading all')
         try:
             return self.__config
         except Exception:
             return None
 
+
 class AppConfig(ConfigBase):
     """ Handle app configuration """
-    def __init__(self):
-        ConfigBase.__init__(self)
+    def __init__(self, basedir=BASEDIR, default=None):
+        ConfigBase.__init__(self, default)
         self.log = logging.getLogger('AppConfig')
         self.log.debug('Started')
-        self.basedir = BASEDIR
+        self.basedir = basedir
 
         self.configpath = os.path.join(self.basedir, 'config')
         self.filterpath = os.path.join(self.basedir, 'filtered')
@@ -225,12 +237,14 @@ class AppConfig(ConfigBase):
         _fd.close()
         return muted
 
+    # TODO: Return saved filters?
     def save_filters(self, filter_list):
         _fd = open(self.filterpath, 'w')
         for expression in filter_list:
             _fd.write(expression + '\n')
         _fd.close()
 
+    # TODO: Return added expresion?
     def append_filter(self, expression):
         for term in self.load_filters():
             if term == expression:
@@ -239,6 +253,7 @@ class AppConfig(ConfigBase):
         _fd.write(expression + '\n')
         _fd.close()
 
+    # TODO: Return removed expression?
     def remove_filter(self, expression):
         new_list = []
         for term in self.load_filters():
@@ -257,6 +272,7 @@ class AppConfig(ConfigBase):
         _fd.close()
         return friends
 
+    # TODO: Return saved friends?
     def save_friends(self, lst):
         _fd = open(self.friendspath, 'w')
         for friend in lst:
@@ -274,10 +290,13 @@ class AppConfig(ConfigBase):
         return accounts
 
     def get_stored_columns(self):
+        columns = []
         stored_cols = self.read_section('Columns')
+        if not stored_cols or len(stored_cols) == 0:
+            return columns
+
         indexes = stored_cols.keys()
         indexes.sort()
-        columns = []
 
         for i in indexes:
             value = stored_cols[i]
@@ -293,10 +312,12 @@ class AppConfig(ConfigBase):
     def get_socket_timeout(self):
         return int(self.read('Advanced', 'socket-timeout'))
 
+    # TODO: Return True when success?
     def delete(self):
         os.remove(self.configpath)
         self.log.debug('Deleted current config. Please restart Turpial')
 
+
 class AccountConfig(ConfigBase):
 
     def __init__(self, account_id):
@@ -306,7 +327,8 @@ class AccountConfig(ConfigBase):
 
         if XDG_CACHE:
             cachedir = BaseDirectory.xdg_cache_home
-            self.imgdir = os.path.join(cachedir, 'turpial', account_id, 'images')
+            self.imgdir = os.path.join(cachedir, 'turpial',
+                                       account_id, 'images')
         else:
             self.imgdir = os.path.join(self.basedir, 'images')
 
@@ -340,7 +362,6 @@ class AccountConfig(ConfigBase):
             return False
         return True
 
-
     # DEPRECATE: Remove verifier in the next stable version
     def save_oauth_credentials(self, key, secret, verifier=None):
         self.write('OAuth', 'key', key)
@@ -381,6 +402,7 @@ class AccountConfig(ConfigBase):
         u = ('%s' % v[:len(v) - 1])[1:]
         return base64.b16decode(u)
 
+    # TODO: Return True on success?
     def dismiss(self):
         if os.path.isdir(self.imgdir):
             shutil.rmtree(self.imgdir)
@@ -392,6 +414,7 @@ class AccountConfig(ConfigBase):
             shutil.rmtree(self.basedir)
             self.log.debug('Removed base directory')
 
+    # TODO: Return True on success?
     def delete_cache(self):
         for root, dirs, files in os.walk(self.imgdir):
             for f in files:
