@@ -28,26 +28,28 @@ class TurpialHTTPBase:
     with end points and services.
 
     You shouldn't instantiate this class, instead you should use the proper
-    implementation for OAuth (:class:`libturpial.api.interfaces.http.TurpialHTTPOAuth`)
-    or Basic Auth (:class:`libturpial.api.interfaces.http.TurpialHTTPBasicAuth`)
+    implementation for OAuth
+    (:class:`libturpial.api.interfaces.http.TurpialHTTPOAuth`)
+    or Basic Auth
+    (:class:`libturpial.api.interfaces.http.TurpialHTTPBasicAuth`)
     or even develop your own implementation if the authentication method is
     not supported.
 
     *base_url* is the part of the URL common for all your requests
-    (http://api.twitter.com/1.1 for example). *proxies* is a dict where you
+    (api.twitter.com/1.1 for example). *proxies* is a dict where you
     define HTTP/HTTPS proxies.
 
     >>> proxies = {
-        "http": "http://10.10.1.10:3128",
-        "https": "https://10.10.1.10:1080",
-    }
+    ...    "http": "http://10.10.1.10:3128",
+    ...    "https": "https://10.10.1.10:1080",
+    ... }
 
     If your proxy uses HTTP authentication then you can set user and password
     with something like this:
 
     >>> proxies = {
-        "http": "http://user:pass@10.10.1.10:3128",
-    }
+    ...    "http": "http://user:pass@10.10.1.10:3128",
+    ... }
 
     *timeout* is the maximum time in seconds that TurpialHTTPBase will wait
     before cancelling the current request. If *timeout* is not specified
@@ -68,7 +70,8 @@ class TurpialHTTPBase:
         else:
             basedir = os.path.dirname(__file__)
             self.ca_certs_file = os.path.realpath(os.path.join(basedir,
-                '..', 'certs', 'cacert.pem'))
+                                                  '..', 'certs',
+                                                  'cacert.pem'))
 
     def __validate_ssl_cert(self, request):
         req = request.split('://')[1]
@@ -88,7 +91,9 @@ class TurpialHTTPBase:
             if field[0][0] == 'commonName':
                 certhost = field[0][1]
                 if certhost != host:
-                    raise ssl.SSLError("Host name '%s' doesn't match certificate host '%s'" % (host, certhost))
+                    ssl_error_msg = "Host name '%s' doesn't match" \
+                                    " certificate host '%s'"
+                    raise ssl.SSLError(ssl_error_msg % (host, certhost))
 
         self.log.debug('Validated SSL cert for host: %s' % host)
 
@@ -103,16 +108,18 @@ class TurpialHTTPBase:
             uri = "%s.%s" % (uri, _format)
 
         return TurpialHTTPRequest(method, uri, _format=_format, params=args,
-                secure=secure, files=files)
+                                  secure=secure, files=files)
 
     def __fetch_resource(self, httpreq):
         if httpreq.method == 'GET':
-            req = requests.get(httpreq.uri, params=httpreq.params, headers=httpreq.headers,
-                    verify=httpreq.secure, proxies=self.proxies, timeout=self.timeout)
+            req = requests.get(httpreq.uri, params=httpreq.params,
+                               headers=httpreq.headers, verify=httpreq.secure,
+                               proxies=self.proxies, timeout=self.timeout)
         elif httpreq.method == 'POST':
-            req = requests.post(httpreq.uri, params=httpreq.params, headers=httpreq.headers,
-                    verify=httpreq.secure, proxies=self.proxies, timeout=self.timeout,
-                    files=httpreq.files)
+            req = requests.post(httpreq.uri, params=httpreq.params,
+                                headers=httpreq.headers, verify=httpreq.secure,
+                                proxies=self.proxies, timeout=self.timeout,
+                                files=httpreq.files)
         if httpreq._format == FORMAT_JSON:
             return req.json()
         else:
@@ -123,7 +130,8 @@ class TurpialHTTPBase:
         This is the method you need to overwrite if you subclass
         :class:`libturpial.api.interfaces.http.TurpialHTTPBase`.
 
-        *httpreq* is the current request (a :class:`libturpial.api.interfaces.http.TurpialHTTPRequest`
+        *httpreq* is the current request
+        (a :class:`libturpial.api.interfaces.http.TurpialHTTPRequest`
         object), you need to apply all the authentication/authorization methods
         to that object and make it valid; then exit. There is no need to return
         any value because all changes are done directly over the object.
@@ -156,9 +164,11 @@ class TurpialHTTPBase:
             proxy_auth = "%s:%s@" % (username, password)
 
         protocol = 'https' if https else 'http'
-        self.proxies[protocol] = "%s://%s%s:%s" % (protocol, proxy_auth, host, port)
+        self.proxies[protocol] = "%s://%s%s:%s" % (protocol, proxy_auth,
+                                                   host, port)
 
-    def get(self, uri, args=None, _format=FORMAT_JSON, base_url=None, secure=False, id_in_url=True):
+    def get(self, uri, args=None, _format=FORMAT_JSON, base_url=None,
+            secure=False, id_in_url=True):
         """
         Performs a GET request against the *uri* resource with *args*. You
         can specify the *_format* ('json' or 'xml') and can specify a different
@@ -167,21 +177,24 @@ class TurpialHTTPBase:
 
         This method is an alias for **request** function using 'GET' as method.
         """
-        return self.request('GET', uri, args, _format, base_url, secure, id_in_url)
+        return self.request('GET', uri, args, _format, base_url, secure,
+                            id_in_url)
 
-    def post(self, uri, args=None, _format=FORMAT_JSON, base_url=None, secure=False, id_in_url=True, files=None):
+    def post(self, uri, args=None, _format=FORMAT_JSON, base_url=None,
+             secure=False, id_in_url=False, files=None):
         """
         Performs a POST request against the *uri* resource with *args*. You
         can specify the *_format* ('json' or 'xml') and can specify a different
         *base_url*. If *secure* is True the request will be perform as HTTPS,
         otherwise it will be performed as HTTP.
 
-        This method is an alias for **request** function using 'POST' as method.
+        This method is an alias for **request** function using 'POST' as method
         """
-        return self.request('POST', uri, args, _format, base_url, secure, id_in_url, files)
+        return self.request('POST', uri, args, _format, base_url, secure,
+                            id_in_url, files)
 
     def request(self, method, uri, args=None, _format=FORMAT_JSON,
-            alt_base_url=None, secure=False, id_in_url=True, files=None):
+                alt_base_url=None, secure=False, id_in_url=False, files=None):
         """
         Performs a GET or POST request against the *uri* resource with
         *args*. You can specify the *_format* ('json' or 'xml') and can specify
@@ -198,7 +211,8 @@ class TurpialHTTPBase:
 
         request_url = "%s%s" % (base_url, uri)
 
-        httpreq = self.__build_request(method, request_url, args, _format, secure, id_in_url, files)
+        httpreq = self.__build_request(method, request_url, args, _format,
+                                       secure, id_in_url, files)
         self.sign_request(httpreq)
         return self.__fetch_resource(httpreq)
 
@@ -207,16 +221,16 @@ class TurpialHTTPOAuth(TurpialHTTPBase):
     """
     Implementation of TurpialHTTPBase for OAuth. *base_url* is the part of
     the URL common for all your requests
-    (http://api.twitter.com/1.1 for example). *oauth_options* is a dict with
+    (api.twitter.com/1.1 for example). *oauth_options* is a dict with
     all the OAuth configuration parameters. It must looks like:
 
     >>> oauth_options = {
-        'consumer_key': 'APP_CONSUMER_KEY',
-        'consumer_secret': 'APP_CONSUMER_SECRET',
-        'request_token_url': 'http://request_url',
-        'authorize_token_url': 'http://authorize_url',
-        'access_token_url': 'http://access_url',
-    }
+    ...    'consumer_key': 'APP_CONSUMER_KEY',
+    ...    'consumer_secret': 'APP_CONSUMER_SECRET',
+    ...    'request_token_url': 'http://request_url',
+    ...    'authorize_token_url': 'http://authorize_url',
+    ...    'access_token_url': 'http://access_url',
+    ... }
 
     *consumer_key* and *consumer_secret* are the credentials for your
     application (they must be provided by the OAuth service).
@@ -235,12 +249,14 @@ class TurpialHTTPOAuth(TurpialHTTPBase):
     * To request an OAuth token create a new TurpialHTTPOAuth object and
       request a token to your service:
 
+    >>> base_url = 'http://api.twitter.com/1.1'
     >>> http = TurpialHTTPOAuth(base_url, oauth_options)
     >>> url_to_auth = http.request_token()
 
     Ask the user go to the *url_to_auth* URL and authorize your app. Then get
     the PIN the service will deliver to your user and authorize the token:
 
+    >>> pin = '123456'
     >>> token = http.authorize_token(pin)
 
     Use this token to store the key, secret and pin in a safe place to use it
@@ -248,11 +264,15 @@ class TurpialHTTPOAuth(TurpialHTTPBase):
 
     >>> http.set_token_info(token.key, token.secret, token.verifier)
 
-    * To use an existing token to fetch a resource create a new TurpialHTTPOAuth
-      object and pass the user_key, user_secret and pin (verifier):
+    * To use an existing token to fetch a resource create a new
+      TurpialHTTPOAuth object and pass the user_key, user_secret and
+      pin (verifier):
 
+    >>> user_key = 'example'
+    >>> user_secret = 'example'
+    >>> verifier = 'example'
     >>> http = TurpialHTTPOAuth(base_url, oauth_options, user_key, user_secret,
-            verifier)
+    ...                         verifier)
 
     * To perform a request use the get or post method:
 
@@ -260,8 +280,9 @@ class TurpialHTTPOAuth(TurpialHTTPBase):
     >>> http.post('/my_second/end_point', args={'arg1': '2'}, _format='json')
 
     """
-    def __init__(self, base_url, oauth_options, user_key=None, user_secret=None,
-            verifier=None, proxies=None, timeout=None):
+    def __init__(self, base_url, oauth_options, user_key=None,
+                 user_secret=None, verifier=None, proxies=None,
+                 timeout=None):
         TurpialHTTPBase.__init__(self, base_url, proxies, timeout)
 
         self.request_token_url = oauth_options['request_token_url']
@@ -269,7 +290,7 @@ class TurpialHTTPOAuth(TurpialHTTPBase):
         self.access_token_url = oauth_options['access_token_url']
 
         self.consumer = oauth.OAuthConsumer(oauth_options['consumer_key'],
-                oauth_options['consumer_secret'])
+                                            oauth_options['consumer_secret'])
         self.sign_method_hmac_sha1 = oauth.OAuthSignatureMethod_HMAC_SHA1()
 
         if user_key and user_secret and verifier:
@@ -282,18 +303,21 @@ class TurpialHTTPOAuth(TurpialHTTPBase):
         """
         Signs the *httpreq* for OAuth using the previously defined user token
         """
-        request = oauth.OAuthRequest.from_consumer_and_token(self.consumer,
-                token=self.token, http_method=httpreq.method,
-                http_url=httpreq.uri, parameters=httpreq.params)
+        request = \
+            oauth.OAuthRequest.from_consumer_and_token(self.consumer,
+                                                       token=self.token,
+                                                       http_method=httpreq.method,  # noqa
+                                                       http_url=httpreq.uri,
+                                                       parameters=httpreq.params)  # noqa
 
         request.sign_request(self.sign_method_hmac_sha1, self.consumer,
-                self.token)
+                             self.token)
         httpreq.headers.update(request.to_header())
 
     def set_token_info(self, user_key, user_secret, verifier):
         """
         Creates a new token using the existing *user_key*, *user_secret* and
-        *verifier*. Use this method 
+        *verifier*. Use this method
         """
         self.token = oauth.OAuthToken(user_key, user_secret)
         self.token.set_verifier(verifier)
@@ -304,7 +328,7 @@ class TurpialHTTPOAuth(TurpialHTTPBase):
         user must access in order to authorize the client.
         """
         oauth_request = oauth.OAuthRequest.from_consumer_and_token(self.consumer,
-                http_url=self.request_token_url)
+                                                                   http_url=self.request_token_url)
 
         oauth_request.sign_request(self.sign_method_hmac_sha1, self.consumer, None)
 
@@ -312,7 +336,7 @@ class TurpialHTTPOAuth(TurpialHTTPBase):
         self.token = oauth.OAuthToken.from_string(req.text)
 
         oauth_request = oauth.OAuthRequest.from_token_and_callback(token=self.token,
-                http_url=self.authorize_token_url)
+                                                                   http_url=self.authorize_token_url)
 
         return oauth_request.to_url()
 
@@ -322,10 +346,11 @@ class TurpialHTTPOAuth(TurpialHTTPBase):
         Returns an :class:`oauth.OAuthToken` object.
         """
         oauth_request = oauth.OAuthRequest.from_consumer_and_token(self.consumer,
-                token=self.token, verifier=pin, http_url=self.access_token_url)
+                                                                   token=self.token,
+                                                                   verifier=pin,
+                                                                   http_url=self.access_token_url)
 
-        oauth_request.sign_request(self.sign_method_hmac_sha1, self.consumer,
-                self.token)
+        oauth_request.sign_request(self.sign_method_hmac_sha1, self.consumer, self.token)
 
         req = requests.get(self.access_token_url, headers=oauth_request.to_header())
         self.token = oauth.OAuthToken.from_string(req.text)
@@ -340,7 +365,7 @@ class TurpialHTTPOAuth(TurpialHTTPBase):
         request = oauth.OAuthRequest.from_consumer_and_token(
             oauth_consumer=self.consumer,
             http_method='POST', http_url=self.access_token_url,
-            parameters = {
+            parameters={
                 'x_auth_mode': 'client_auth',
                 'x_auth_username': username,
                 'x_auth_password': password
@@ -357,9 +382,9 @@ class TurpialHTTPOAuth(TurpialHTTPBase):
 class TurpialHTTPBasicAuth(TurpialHTTPBase):
     """
     Implementation of TurpialHTTPBase for the HTTP Basic Authentication.
-    *base_url* is the part of the URL common for all your requests
-    (http://identi.ca/api for example). *username* and *password* are the username
-    credentials. *proxies* and *timeout* work in the same way that in
+    *base_url* is the part of the URL common for all your requests.
+    *username* and *password* are the username credentials.
+    *proxies* and *timeout* work in the same way that in
     :class:`libturpial.api.interfaces.http.TurpialHTTPBase`.
 
     *proxies* and *timeout* work in the same way that in
@@ -368,6 +393,9 @@ class TurpialHTTPBasicAuth(TurpialHTTPBase):
     * To fetch a resource using Basic Authentication just create a new
       TurpialHTTPBasicAuth object and pass the user credentials as parameters:
 
+    >>> base_url = 'http://identi.ca/api'
+    >>> username = 'example'
+    >>> password = 'example'
     >>> http = TurpialHTTPBasicAuth(base_url, username, password)
 
     Then perform the request desired using get or post methods:
@@ -395,13 +423,12 @@ class TurpialHTTPBasicAuth(TurpialHTTPBase):
         httpreq.headers["Authorization"] = self.basic_auth_info
 
 
-
 class TurpialHTTPRequest:
     """
     Encapsulate an URL request into a python object
     """
     def __init__(self, method, uri, headers=None, params=None,
-            _format=FORMAT_JSON, secure=False, files=None):
+                 _format=FORMAT_JSON, secure=False, files=None):
 
         self.uri = uri
         self.method = method
