@@ -4,8 +4,8 @@
 
 import json
 
-from libturpial.api.models.media import *
-from libturpial.lib.services.media.preview.base import *
+from libturpial.api.models.media import Media
+from libturpial.lib.services.media.preview.base import PreviewMediaService
 
 CLIENT_ID = '3ycgz7gzer80068s80t4xl1cs'
 
@@ -21,5 +21,9 @@ class ViameMediaContent(PreviewMediaService):
                                                                    CLIENT_ID)
         resp = json.loads(self._get_content_from_url(req_url))
         media_content_url = resp['response']['post']['media_url']
+        info_ = {
+            'source_url': media_content_url,
+            'original_url': url,
+        }
         rawimg = self._get_content_from_url(media_content_url)
-        return Media.new_image(url, rawimg)
+        return Media.new_image(url, rawimg, info=info_)
